<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh">
<context>
    <name>FQTerm::FQTermAutoUpdater</name>
    <message>
        <source>FQTerm Update Notifier</source>
        <translation>FQTerm 升级通知</translation>
    </message>
    <message>
        <source>FQTerm update available.
Press OK to visit our download list,
Discard for a next-time-startup inform,
Ignore for no more notification.</source>
        <translation type="obsolete">FQTerm 新版本可用
&quot;确认&quot;访问下载列表
“取消&quot;等待下次启动提示
&quot;忽略&quot;忽略本次更新.</translation>
    </message>
    <message>
        <source>FQTerm update available.
Press OK to visit our download list,
Discard for a future prompt,
Ignore for no more notification.</source>
        <translation>FQTerm 新版本可用
&quot;确认&quot;访问下载列表
“取消&quot;将来提示
&quot;忽略&quot;忽略本次更新.</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermFrame</name>
    <message>
        <source>Cascade</source>
        <translation>层叠</translation>
    </message>
    <message>
        <source>FQTerm will keep running in the system tray.
To terminate the program, choose exit in the tray menu.</source>
        <translation>FQTerm已经最小化至系统托盘.</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>平铺</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>主窗口</translation>
    </message>
    <message>
        <source>Quick Login</source>
        <translation>快速连接</translation>
    </message>
    <message>
        <source>This will take effect after restart,
please close all windows and restart.</source>
        <translation type="obsolete">您的设置将在重新启动程序后生效,
请关闭所有窗口后重启程序.</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>断开连接</translation>
    </message>
    <message>
        <source>Reconnect When Disconnected By Host</source>
        <translation>当主机断开时自动重连</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation>连接(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>断开连接(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Address book</source>
        <translation>地址簿(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Quick login</source>
        <translation>快速连接(&amp;Q)</translation>
    </message>
    <message>
        <source>Quick login</source>
        <translation type="obsolete">快速连接</translation>
    </message>
    <message>
        <source>&amp;Exit</source>
        <translation>退出(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>粘贴(&amp;P)</translation>
    </message>
    <message>
        <source>C&amp;opy with color</source>
        <translation>彩色复制(&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Rectangle select</source>
        <translation>矩形选择(&amp;R)</translation>
    </message>
    <message>
        <source>Auto copy &amp;select</source>
        <translation>自动复制(&amp;s)</translation>
    </message>
    <message>
        <source>P&amp;aste with wordwrap</source>
        <translation>自动换行粘贴(&amp;a)</translation>
    </message>
    <message>
        <source>Paste &amp;with color</source>
        <translation>彩色粘贴(&amp;w)</translation>
    </message>
    <message>
        <source>&amp;None</source>
        <translation>&amp;None</translation>
    </message>
    <message>
        <source>&amp;ESC ESC [</source>
        <translation>&amp;ESC ESC [</translation>
    </message>
    <message>
        <source>Ctrl+&amp;U [</source>
        <translation>Ctrl+&amp;U [</translation>
    </message>
    <message>
        <source>&amp;Custom...</source>
        <translation>自定义(&amp;C)...</translation>
    </message>
    <message>
        <source>Clipboard &amp;encoding</source>
        <translation>剪贴板编码(&amp;e)</translation>
    </message>
    <message>
        <source>&amp;GBK</source>
        <translation>&amp;GBK</translation>
    </message>
    <message>
        <source>&amp;Big5</source>
        <translation>&amp;Big5</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>视图(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>字体(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="obsolete">颜色(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation>刷新(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Language</source>
        <translation>语言(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;English</source>
        <translation>&amp;English</translation>
    </message>
    <message>
        <source>&amp;Simplified Chinese</source>
        <translation type="obsolete">简体中文(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Traditional Chinese</source>
        <translation type="obsolete">繁體中文(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;UI font</source>
        <translation>界面字体(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Themes</source>
        <translation>主题(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <source>Boss &amp;Color</source>
        <translation>保护色(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;ScrollBar</source>
        <translation>滚动条(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation>隐藏(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Left</source>
        <translation>左侧(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Right</source>
        <translation>右侧(&amp;R)</translation>
    </message>
    <message>
        <source>Status &amp;Bar</source>
        <translation>状态条(&amp;B)</translation>
    </message>
    <message>
        <source>S&amp;witch Bar</source>
        <translation>任务栏(&amp;w)</translation>
    </message>
    <message>
        <source>&amp;Option</source>
        <translation>选项(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Setting for currrent session</source>
        <translation type="obsolete">当前连接属性(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Default setting</source>
        <translation>缺省设置(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Preference</source>
        <translation type="obsolete">偏好(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Special</source>
        <translation>特殊(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Copy article</source>
        <translation>全文下载(&amp;C)</translation>
    </message>
    <message>
        <source>Anti &amp;idle</source>
        <translation>防发呆(&amp;i)</translation>
    </message>
    <message>
        <source>Auto &amp;reply</source>
        <translation>自动回复(&amp;r)</translation>
    </message>
    <message>
        <source>&amp;View messages</source>
        <translation>查看即时消息(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Beep </source>
        <translation>蜂鸣(&amp;B) </translation>
    </message>
    <message>
        <source>&amp;Mouse support</source>
        <translation>鼠标支持(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Image viewer</source>
        <translation>图像预览器(&amp;I)</translation>
    </message>
    <message>
        <source>Scrip&amp;t</source>
        <translation>脚本(&amp;t)</translation>
    </message>
    <message>
        <source>&amp;Run...</source>
        <translation>运行(&amp;R)...</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>停止(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Windows</source>
        <translation>窗口(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>About &amp;FQTerm</source>
        <translation>关于FQTerm(&amp;Q)</translation>
    </message>
    <message>
        <source>FQTerm&amp;apos;s &amp;Homepage</source>
        <translation type="obsolete">主页(&amp;H)</translation>
    </message>
    <message>
        <source>Key Setup</source>
        <translation>自定义按键组合</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Sorry, image viewer is not supported currently.</source>
        <translation type="obsolete">对不起,图像预览器仍处于开发中.</translation>
    </message>
    <message>
        <source>FQTerm&apos;s &amp;Homepage</source>
        <translation>主页(&amp;H)</translation>
    </message>
    <message>
        <source>FQTerm</source>
        <translation>FQTerm</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Alt+Right</source>
        <translation type="obsolete">Alt+Right</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+Left</translation>
    </message>
    <message>
        <source>Ctrl+Alt</source>
        <translation>Ctrl+Alt</translation>
    </message>
    <message>
        <source>F2</source>
        <translation type="obsolete">F2</translation>
    </message>
    <message>
        <source>F3</source>
        <translation type="obsolete">F3</translation>
    </message>
    <message>
        <source>Ctrl+Insert</source>
        <translation type="obsolete">Ctrl+Insert</translation>
    </message>
    <message>
        <source>Shift+Insert</source>
        <translation type="obsolete">Shift+Insert</translation>
    </message>
    <message>
        <source>F5</source>
        <translation type="obsolete">F5</translation>
    </message>
    <message>
        <source>F6</source>
        <translation type="obsolete">F6</translation>
    </message>
    <message>
        <source>F12</source>
        <translation type="obsolete">F12</translation>
    </message>
    <message>
        <source>F9</source>
        <translation type="obsolete">F9</translation>
    </message>
    <message>
        <source>F10</source>
        <translation type="obsolete">F10</translation>
    </message>
    <message>
        <source>F7</source>
        <translation type="obsolete">F7</translation>
    </message>
    <message>
        <source>F8</source>
        <translation type="obsolete">F8</translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="obsolete">F1</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation></translation>
    </message>
    <message>
        <source>+Right</source>
        <translation></translation>
    </message>
    <message>
        <source>+Left</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+Meta</source>
        <translation></translation>
    </message>
    <message>
        <source>Set Terminal Fonts</source>
        <translation>设置终端字体</translation>
    </message>
    <message>
        <source> Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>&amp;Color Setting</source>
        <translation>颜色设置(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Use ANSI Color</source>
        <translation>使用ANSI颜色(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Setting for current session</source>
        <translation>当前连接属性(&amp;S)</translation>
    </message>
    <message>
        <source>Google It</source>
        <translation>Google一下</translation>
    </message>
    <message>
        <source>External Editor</source>
        <translation>外部编辑器</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>偏好(&amp;P)...</translation>
    </message>
    <message>
        <source>&amp;Shortcut Setting</source>
        <translation>快捷键设置(&amp;S)</translation>
    </message>
    <message>
        <source>Run &amp;Python...</source>
        <translation>执行Python脚本(&amp;P)...</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermScreen</name>
    <message>
        <source>Shift+PageUp</source>
        <translation>Shift+PageUp</translation>
    </message>
    <message>
        <source>Shift+PageDown</source>
        <translation>Shift+PageDown</translation>
    </message>
    <message>
        <source>Shift+Up</source>
        <translation>Shift+Up</translation>
    </message>
    <message>
        <source>Shift+Down</source>
        <translation>Shift+Down</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermScriptEngine</name>
    <message>
        <source>FQTerm</source>
        <translation>FQTerm</translation>
    </message>
    <message>
        <source>Unable to open the script file
</source>
        <translation>无法打开脚本文件</translation>
    </message>
    <message>
        <source>uncaught exception at line </source>
        <translation>未捕获的异常，所在行数：</translation>
    </message>
</context>
<context>
    <name>FQTerm::FQTermWindow</name>
    <message>
        <source>Not Connected</source>
        <translation type="obsolete">未连接</translation>
    </message>
    <message>
        <source>Preview image</source>
        <translation>预览图片</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>保存为...</translation>
    </message>
    <message>
        <source>Open link</source>
        <translation>打开链接</translation>
    </message>
    <message>
        <source>Copy link address</source>
        <translation>复制链接地址</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Copy Article</source>
        <translation>全文下载</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>颜色</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="obsolete">打开URL</translation>
    </message>
    <message>
        <source>resolving host name</source>
        <translation type="obsolete">解析主机名称</translation>
    </message>
    <message>
        <source>host found</source>
        <translation type="obsolete">找到主机</translation>
    </message>
    <message>
        <source>host not found</source>
        <translation type="obsolete">主机未找到</translation>
    </message>
    <message>
        <source>connecting...</source>
        <translation type="obsolete">连接中...</translation>
    </message>
    <message>
        <source>connected</source>
        <translation type="obsolete">已连接</translation>
    </message>
    <message>
        <source>connected to proxy</source>
        <translation type="obsolete">已连接至代理</translation>
    </message>
    <message>
        <source>proxy authentation</source>
        <translation type="obsolete">代理权限</translation>
    </message>
    <message>
        <source>proxy failed</source>
        <translation type="obsolete">代理失败</translation>
    </message>
    <message>
        <source>connection refused</source>
        <translation type="obsolete">连接被拒绝</translation>
    </message>
    <message>
        <source>error when reading from server</source>
        <translation type="obsolete">读取服务器数据失败</translation>
    </message>
    <message>
        <source>connection closed</source>
        <translation type="obsolete">连接已关闭</translation>
    </message>
    <message>
        <source>connection close finished</source>
        <translation type="obsolete">完成关闭连接</translation>
    </message>
    <message>
        <source>connect to host via proxy</source>
        <translation type="obsolete">通过代理连接主机</translation>
    </message>
    <message>
        <source>error in gethostbyname</source>
        <translation type="obsolete">gethostbyname错误</translation>
    </message>
    <message>
        <source>error in startup winsock</source>
        <translation type="obsolete">winsock启动错误</translation>
    </message>
    <message>
        <source>error in connection</source>
        <translation type="obsolete">连接错误</translation>
    </message>
    <message>
        <source>error in proxy</source>
        <translation type="obsolete">代理错误</translation>
    </message>
    <message>
        <source>time out!</source>
        <translation type="obsolete">超时!</translation>
    </message>
    <message>
        <source>time out after trying %1 times</source>
        <translation type="obsolete">超时,已重试:%1次</translation>
    </message>
    <message>
        <source>canceled by remote peer %1</source>
        <translation type="obsolete">已被%1取消</translation>
    </message>
    <message>
        <source>unhandled header %1 at state %2</source>
        <translation type="obsolete">未处理的头部%1,状态%2</translation>
    </message>
    <message>
        <source>msg from remote peer: %1</source>
        <translation type="obsolete">信息:%1</translation>
    </message>
    <message>
        <source>data errors %1</source>
        <translation type="obsolete">数据错误%1</translation>
    </message>
    <message>
        <source>falied to write file</source>
        <translation type="obsolete">写文件失败</translation>
    </message>
    <message>
        <source>skipping file %1</source>
        <translation type="obsolete">跳过文件%1</translation>
    </message>
    <message>
        <source>Ctrl+Insert</source>
        <translation>Ctrl+Insert</translation>
    </message>
    <message>
        <source>Shift+Insert</source>
        <translation>Shift+Insert</translation>
    </message>
    <message>
        <source>F9</source>
        <translation type="obsolete">F9</translation>
    </message>
    <message>
        <source>FQTerm</source>
        <translation>FQTerm</translation>
    </message>
    <message>
        <source>Connected,Do you still want to exit?</source>
        <translation type="obsolete">已连接, 确认退出?</translation>
    </message>
    <message>
        <source>UserCancel</source>
        <translation type="obsolete">用户取消</translation>
    </message>
    <message>
        <source>Session error</source>
        <translation>Session 错误</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未连接</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source> Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>Still connected, do you really want to exit?</source>
        <translation>已连接, 确认退出?</translation>
    </message>
    <message>
        <source>Time out!</source>
        <translation>超时!</translation>
    </message>
    <message>
        <source>Time out after trying %1 times</source>
        <translation>超时,已重试:%1次</translation>
    </message>
    <message>
        <source>Canceled by remote peer %1</source>
        <translation>已被%1取消</translation>
    </message>
    <message>
        <source>Unhandled header %1 at state %2</source>
        <translation>未处理的头部%1,状态%2</translation>
    </message>
    <message>
        <source>Msg from remote peer: %1</source>
        <translation>信息:%1</translation>
    </message>
    <message>
        <source>Data errors %1</source>
        <translation>数据错误%1</translation>
    </message>
    <message>
        <source>Falied to write file</source>
        <translation>写文件失败</translation>
    </message>
    <message>
        <source>Skipping file %1</source>
        <translation>跳过文件%1</translation>
    </message>
    <message>
        <source>Resolving host name</source>
        <translation>解析主机名称</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>找到主机</translation>
    </message>
    <message>
        <source>Host not found</source>
        <translation>主机未找到</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>连接中...</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已连接</translation>
    </message>
    <message>
        <source>Connected to proxy</source>
        <translation>已连接至代理</translation>
    </message>
    <message>
        <source>Proxy authentation</source>
        <translation>代理权限</translation>
    </message>
    <message>
        <source>Proxy failed</source>
        <translation>代理失败</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>连接被拒绝</translation>
    </message>
    <message>
        <source>Error when reading from server</source>
        <translation>读取服务器数据失败</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>连接已关闭</translation>
    </message>
    <message>
        <source>Connection close finished</source>
        <translation>完成关闭连接</translation>
    </message>
    <message>
        <source>Connect to host via proxy</source>
        <translation>通过代理连接主机</translation>
    </message>
    <message>
        <source>Error in gethostbyname</source>
        <translation>gethostbyname错误</translation>
    </message>
    <message>
        <source>Error in startup winsock</source>
        <translation>winsock启动错误</translation>
    </message>
    <message>
        <source>Error in connection</source>
        <translation>连接错误</translation>
    </message>
    <message>
        <source>Error in proxy</source>
        <translation>代理错误</translation>
    </message>
    <message>
        <source>User Cancel</source>
        <translation>用户取消</translation>
    </message>
    <message>
        <source>URL Dialog</source>
        <translation>打开URL</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>打开URL(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Waiting header...</source>
        <translation>获取文件头...</translation>
    </message>
    <message>
        <source>Open Selected As Url</source>
        <translation>将选中文字作为URL打开</translation>
    </message>
    <message>
        <source>Google Selected Text!</source>
        <translation>Google选中文字!</translation>
    </message>
    <message>
        <source>Font Selector</source>
        <translation>字体选择</translation>
    </message>
</context>
</TS>
